@@ -7,7 +7,8 @@ from mandaw.line import Line
 from mandaw.color import Color
 from mandaw.sprite import Sprite
 from mandaw.text import Text
-from mandaw.input import Controls
+from mandaw.input import Input
 from mandaw.audio import Audio
 from mandaw.animation import Animation
 from mandaw.light import Light
+from mandaw.particle import ParticleSpawner
