@@ -1,6 +1,5 @@
-import time
-import pygame
-from mandaw.input import Controls
+from mandaw.input import Input
+import os, time, sys, pygame
 
 class Mandaw:
     def __init__(self, title = "Mandaw", width = 800, height = 600, bg_color = "black"):
@@ -8,6 +7,7 @@ class Mandaw:
         self.height = height
         self.title = title
         self.bg_color = bg_color
+        self.background = None
         self.fps = 60
         self.done = False
 
@@ -19,9 +19,13 @@ class Mandaw:
 
         self.window = pygame.display.set_mode((self.width, self.height))
         pygame.display.set_caption(self.title)
+        path = os.path.dirname(os.path.abspath(__file__))
+        self.icon = os.path.join(path, "./assets/mandaw.png")
+        image = pygame.image.load(self.icon)
+        pygame.display.set_icon(image)
         self.window.fill(self.bg_color)
 
-        self.controls = Controls()
+        self.input = Input()
 
         self.keys = {
             "UP":pygame.K_UP, "DOWN":pygame.K_DOWN,
@@ -76,7 +80,11 @@ class Mandaw:
 
             "HOME":pygame.K_HOME, "INSERT":pygame.K_INSERT,
             "DELETE":pygame.K_DELETE, "RETURN":pygame.K_RETURN,
-            "SPACE":pygame.K_SPACE, "PLUS":pygame.K_PLUS
+            "SPACE":pygame.K_SPACE, "PLUS":pygame.K_PLUS,
+        }
+
+        self.mouse_buttons = {
+            "LEFT":0, "MIDDLE":1, "RIGHT":2
         }
 
     def run(self):
@@ -89,7 +97,7 @@ class Mandaw:
         self.dt *= 60
         self.last_time = time.time()
 
-        self.controls.update()
+        self.input.update()
 
         for event in pygame.event.get():
             if event.type == pygame.QUIT:
@@ -97,4 +105,10 @@ class Mandaw:
                 pygame.quit()
                 quit()
 
+        if self.input.get_key_pressed(self.keys["F5"]):
+            os.execl(sys.executable, sys.executable, *sys.argv)
+
         self.window.fill(self.bg_color)
+
+        if self.background != None:
+            self.background.draw()
\ No newline at end of file
